@@ -50,7 +50,7 @@ usage() {
     echo ""
 }
 
-NVIDIA_BUG_REPORT_CHANGE='$Change: 16324622 $'
+NVIDIA_BUG_REPORT_CHANGE='$Change: 22842053 $'
 NVIDIA_BUG_REPORT_VERSION=`echo "$NVIDIA_BUG_REPORT_CHANGE" | tr -c -d "[:digit:]"`
 
 # Set the default filename so that it won't be empty in the usage message
@@ -93,7 +93,7 @@ echo_metadata() {
     if [ $? -ne 0 ]; then
         # Run dumb ls -l. We might not get one-second mtime granularity, but
         # that is probably okay.
-        ls -l "$1"
+        ls -l "$1" 2>&1
     fi
 }
 
@@ -416,13 +416,13 @@ append_file_or_dir_silent /usr/share/nvidia/nvidia-application-profiles-*-rc
 (
     echo "____________________________________________"
     echo ""
-    echo "Scanning kernel log files for NVRM messages:"
+    echo "Scanning kernel log files for NVIDIA kernel messages:"
     echo ""
 
     for i in /var/log/messages /var/log/kernel.log ; do
         if [ -f $i -a -r $i ]; then
             echo "  $i:"
-            ( cat $i | grep NVRM ) 2> /dev/null
+            ( cat $i | grep -e NVRM -e nvidia- ) 2> /dev/null
         else
             echo "$i is not readable"
         fi
